@@ -208,11 +208,9 @@ def parse_hotspot1_spot_score(path_to_hotspot1_spot_score):
         next(f)
         raw_values = f.readline()
     values = raw_values.strip().split()
-    qc_dict["# of read tags provided"] = try_converting_to_numeric(values[0])
-    qc_dict["# of read tags that were in hotspots"] = try_converting_to_numeric(
-        values[1]
-    )
-    qc_dict["SPOT1 score"] = try_converting_to_numeric(values[2])
+    qc_dict["total_tags"] = try_converting_to_numeric(values[0])
+    qc_dict["hotspot_tags"] = try_converting_to_numeric(values[1])
+    qc_dict["spot1_score"] = try_converting_to_numeric(values[2])
     return qc_dict
 
 
@@ -265,7 +263,7 @@ def parse_picard_duplication_metrics(path_to_duplication_metrics):
         "UNPAIRED_READS_EXAMINED"
     )
     encode_formatted_metrics["Reads Examined"] = (
-        encode_formatted_metrics["Read Pairs Examined"]
+        2 * encode_formatted_metrics["Read Pairs Examined"]
         + encode_formatted_metrics["Unpaired Reads Examined"]
     )
     encode_formatted_metrics["Unmapped Reads"] = raw_metrics.get("UNMAPPED_READS")
@@ -273,7 +271,7 @@ def parse_picard_duplication_metrics(path_to_duplication_metrics):
         "UNPAIRED_READ_DUPLICATES"
     )
     encode_formatted_metrics["Read Duplicates"] = (
-        encode_formatted_metrics["Read Pair Duplicates"]
+        2 * encode_formatted_metrics["Read Pair Duplicates"]
         + encode_formatted_metrics["Unpaired Read Duplicates"]
     )
 
@@ -291,7 +289,15 @@ def parse_picard_insert_size_metrics(path_to_insert_size_metrics):
 
 
 def parse_insert_size_info(path_to_insert_size_info):
-    return parse_key_value_tsv(path_to_insert_size_info)
+    raw_insert_size_info = parse_key_value_tsv(path_to_insert_size_info)
+    encode_formatted_insert_size_info = {}
+    encode_formatted_insert_size_info[
+        "fourier_transform_eleven"
+    ] = raw_insert_size_info["insert-ft-eleven"]
+    encode_formatted_insert_size_info["large_small_ratio"] = raw_insert_size_info[
+        "insert-ls-ratio"
+    ]
+    return encode_formatted_insert_size_info
 
 
 def parse_samtools_stats(path_to_samtools_stats):
